struct PendingRequestQueues<K, E, S> {
executions: VecDeque<E>,
suggestions: VecDeque<(K, S)>,
execution_capacity: usize,
suggestion_capacity: usize,
prefer_execution: bool,
}Expand description
Independently bounded execution and suggestion queues.
Suggestions are coalesced by sender and the two queues are drained fairly. This keeps a client producing suggestion traffic from consuming execution capacity or the entire tick budget.
Fields
executions: VecDeque<E>suggestions: VecDeque<(K, S)>execution_capacity: usizesuggestion_capacity: usizeprefer_execution: boolImplementations
Sourceimpl<K: Eq, E, S> PendingRequestQueues<K, E, S>
impl<K: Eq, E, S> PendingRequestQueues<K, E, S>
const fn new(execution_capacity: usize, suggestion_capacity: usize) -> Self
fn submit_execution(&mut self, request: E) -> Result<(), CommandQueueFull>
fn submit_suggestions( &mut self, key: K, request: S, ) -> Result<(), CommandQueueFull>
fn pop_front_where( &mut self, execution_allowed: impl FnMut(&E) -> bool, ) -> Option<PendingRequest<E, S>>
fn pop_allowed_execution( &mut self, execution_allowed: &mut impl FnMut(&E) -> bool, ) -> Option<E>
fn clear(&mut self)